@@ -177,7 +177,7 @@ ldFormula <- function(formula, data = NULL, triple = c(3,3,3),
   X <- model.matrix(f, data = mf,rhs = 1)
   Z <- model.matrix(f, data = mf,rhs = 2)
 
-  index <- order(id, time)
+  index <- order(id[[1L]], time[[1L]])
 
   Y    <- Y[index, ]
   id   <- id[index, ]
@@ -193,27 +193,26 @@ ldFormula <- function(formula, data = NULL, triple = c(3,3,3),
   }
   
   # covariates from rhs of the formula
-  # cat("dim(X) = ", dim(X), "\n")
-  # cat("dim(Z) = ", dim(Z), "\n")
   Xtmp <- X[index, -1]
   Ztmp <- Z[index, -1]
-  # cat("Xtmp = ", Xtmp, "\n")
-  # cat("Ztmp = ", Ztmp, "\n")
-  
+
   # covariates based on polynomials of time
   X <- rep(1, length(time))
   Z <- rep(1, length(time))
-  for (i in 1:triple[1]) X = cbind(X, time^i)
-  for (i in 1:triple[2]) Z = cbind(Z, time^i)
-  # cat("X = ", X[2,], "\n")
-  # cat("Z = ", Z[2,], "\n")
+  if (triple[1] != 0)
+    for (i in 1:triple[1]) X = cbind(X, time^i)
+  else
+    X <- as.matrix(X, ncol = 1)
   
+  if (triple[2] != 0)
+    for (i in 1:triple[2]) Z = cbind(Z, time^i)
+  else
+    Z <- as.matrix(Z, ncol = 1)
+
   # combine two parts of the covariates
   X <- cbind(X, Xtmp)
   Z <- cbind(Z, Ztmp)
-  # cat("X = ", X[2,], "\n")
-  # cat("Z = ", Z[2,], "\n")
-  
+
   W <- NULL
   for (i in 1:length(m))
   {
